export declare const unregisteredAddressesSchema: {
    $id: string;
    type: string;
    properties: {
        unregisteredAddresses: {
            type: string;
            fieldNumber: number;
            items: {
                type: string;
                properties: {
                    address: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    balance: {
                        dataType: string;
                        fieldNumber: number;
                    };
                };
                required: string[];
            };
        };
    };
    required: string[];
};
export declare const accountSchema: {
    $id: string;
    type: string;
    properties: {
        address: {
            dataType: string;
            fieldNumber: number;
        };
        token: {
            type: string;
            properties: {
                balance: {
                    fieldNumber: number;
                    dataType: string;
                };
            };
            fieldNumber: number;
        };
        sequence: {
            type: string;
            properties: {
                nonce: {
                    fieldNumber: number;
                    dataType: string;
                };
            };
            fieldNumber: number;
        };
        keys: {
            type: string;
            properties: {
                numberOfSignatures: {
                    dataType: string;
                    fieldNumber: number;
                };
                mandatoryKeys: {
                    type: string;
                    items: {
                        dataType: string;
                    };
                    fieldNumber: number;
                };
                optionalKeys: {
                    type: string;
                    items: {
                        dataType: string;
                    };
                    fieldNumber: number;
                };
            };
            fieldNumber: number;
        };
        dpos: {
            type: string;
            properties: {
                delegate: {
                    type: string;
                    fieldNumber: number;
                    properties: {
                        username: {
                            dataType: string;
                            fieldNumber: number;
                        };
                        pomHeights: {
                            type: string;
                            items: {
                                dataType: string;
                            };
                            fieldNumber: number;
                        };
                        consecutiveMissedBlocks: {
                            dataType: string;
                            fieldNumber: number;
                        };
                        lastForgedHeight: {
                            dataType: string;
                            fieldNumber: number;
                        };
                        isBanned: {
                            dataType: string;
                            fieldNumber: number;
                        };
                        totalVotesReceived: {
                            dataType: string;
                            fieldNumber: number;
                        };
                    };
                    required: string[];
                };
                sentVotes: {
                    type: string;
                    fieldNumber: number;
                    items: {
                        type: string;
                        properties: {
                            delegateAddress: {
                                dataType: string;
                                fieldNumber: number;
                            };
                            amount: {
                                dataType: string;
                                fieldNumber: number;
                            };
                        };
                        required: string[];
                    };
                };
                unlocking: {
                    type: string;
                    fieldNumber: number;
                    items: {
                        type: string;
                        properties: {
                            delegateAddress: {
                                dataType: string;
                                fieldNumber: number;
                            };
                            amount: {
                                dataType: string;
                                fieldNumber: number;
                            };
                            unvoteHeight: {
                                dataType: string;
                                fieldNumber: number;
                            };
                        };
                        required: string[];
                    };
                };
            };
            fieldNumber: number;
        };
    };
    required: string[];
};
export declare const signingBlockHeaderSchema: {
    $id: string;
    type: string;
    properties: {
        version: {
            dataType: string;
            fieldNumber: number;
        };
        timestamp: {
            dataType: string;
            fieldNumber: number;
        };
        height: {
            dataType: string;
            fieldNumber: number;
        };
        previousBlockID: {
            dataType: string;
            fieldNumber: number;
        };
        transactionRoot: {
            dataType: string;
            fieldNumber: number;
        };
        generatorPublicKey: {
            dataType: string;
            fieldNumber: number;
        };
        reward: {
            dataType: string;
            fieldNumber: number;
        };
        asset: {
            dataType: string;
            fieldNumber: number;
        };
    };
    required: string[];
};
export declare const blockHeaderSchema: {
    $id: string;
    properties: {
        signature: {
            dataType: string;
            fieldNumber: number;
        };
        version: {
            dataType: string;
            fieldNumber: number;
        };
        timestamp: {
            dataType: string;
            fieldNumber: number;
        };
        height: {
            dataType: string;
            fieldNumber: number;
        };
        previousBlockID: {
            dataType: string;
            fieldNumber: number;
        };
        transactionRoot: {
            dataType: string;
            fieldNumber: number;
        };
        generatorPublicKey: {
            dataType: string;
            fieldNumber: number;
        };
        reward: {
            dataType: string;
            fieldNumber: number;
        };
        asset: {
            dataType: string;
            fieldNumber: number;
        };
    };
    type: string;
    required: string[];
};
export declare const transactionSchema: {
    $id: string;
    type: string;
    required: string[];
    properties: {
        moduleID: {
            dataType: string;
            fieldNumber: number;
            minimum: number;
        };
        assetID: {
            dataType: string;
            fieldNumber: number;
        };
        nonce: {
            dataType: string;
            fieldNumber: number;
        };
        fee: {
            dataType: string;
            fieldNumber: number;
        };
        senderPublicKey: {
            dataType: string;
            fieldNumber: number;
            minLength: number;
            maxLength: number;
        };
        asset: {
            dataType: string;
            fieldNumber: number;
        };
        signatures: {
            type: string;
            items: {
                dataType: string;
            };
            fieldNumber: number;
        };
    };
};
export declare const voteWeightsSchema: {
    $id: string;
    type: string;
    properties: {
        voteWeights: {
            type: string;
            fieldNumber: number;
            items: {
                type: string;
                properties: {
                    round: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    delegates: {
                        type: string;
                        fieldNumber: number;
                        items: {
                            type: string;
                            properties: {
                                address: {
                                    dataType: string;
                                    fieldNumber: number;
                                };
                                voteWeight: {
                                    dataType: string;
                                    fieldNumber: number;
                                };
                            };
                        };
                    };
                };
            };
        };
    };
    required: string[];
};
export declare const genesisLegacyStoreSchema: {
    $id: string;
    type: string;
    required: string[];
    properties: {
        accounts: {
            type: string;
            fieldNumber: number;
            items: {
                type: string;
                required: string[];
                properties: {
                    address: {
                        dataType: string;
                        minLength: number;
                        maxLength: number;
                        fieldNumber: number;
                    };
                    balance: {
                        dataType: string;
                        fieldNumber: number;
                    };
                };
            };
        };
    };
};
export declare const genesisAuthStoreSchema: {
    $id: string;
    type: string;
    required: string[];
    properties: {
        authDataSubstore: {
            type: string;
            fieldNumber: number;
            items: {
                type: string;
                required: string[];
                properties: {
                    address: {
                        dataType: string;
                        format: string;
                        fieldNumber: number;
                    };
                    authAccount: {
                        type: string;
                        fieldNumber: number;
                        required: string[];
                        properties: {
                            nonce: {
                                dataType: string;
                                fieldNumber: number;
                            };
                            numberOfSignatures: {
                                dataType: string;
                                fieldNumber: number;
                            };
                            mandatoryKeys: {
                                type: string;
                                fieldNumber: number;
                                items: {
                                    dataType: string;
                                };
                            };
                            optionalKeys: {
                                type: string;
                                fieldNumber: number;
                                items: {
                                    dataType: string;
                                };
                            };
                        };
                    };
                };
            };
        };
    };
};
