"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFiles = exports.createTarball = exports.copyFile = exports.read = exports.write = exports.copyDir = exports.rmdir = exports.exists = exports.extractTarBall = void 0;
const tslib_1 = require("tslib");
const tar = tslib_1.__importStar(require("tar"));
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const extractTarBall = async (srcFilePath, destDirPath) => new Promise((resolve, reject) => {
    if (fs_1.default.existsSync(destDirPath))
        fs_1.default.rmdirSync(destDirPath, { recursive: true });
    fs_1.default.mkdirSync(destDirPath, { recursive: true });
    const fileStream = fs_1.default.createReadStream(srcFilePath);
    fileStream.pipe(tar.extract({ cwd: destDirPath }));
    fileStream.on('error', err => reject(new Error(err)));
    fileStream.on('end', () => setTimeout(resolve.bind(null, true), 100));
});
exports.extractTarBall = extractTarBall;
const exists = async (inputPath) => {
    try {
        await fs_1.default.promises.access(inputPath);
        return true;
    }
    catch (_) {
        return false;
    }
};
exports.exists = exists;
const rmdir = async (directoryPath, options = {}) => new Promise((resolve, reject) => {
    fs_1.default.rmdir(directoryPath, options, err => {
        if (err)
            return reject(err);
        return resolve(true);
    });
});
exports.rmdir = rmdir;
const copyDir = async (src, dest) => {
    await fs_1.default.promises.mkdir(dest, { recursive: true });
    const files = await fs_1.default.promises.readdir(src, { withFileTypes: true });
    for (const fileInfo of files) {
        const srcPath = path_1.default.join(src, fileInfo.name);
        const destPath = path_1.default.join(dest, fileInfo.name);
        fileInfo.isDirectory()
            ? await (0, exports.copyDir)(srcPath, destPath)
            : await fs_1.default.promises.copyFile(srcPath, destPath);
    }
};
exports.copyDir = copyDir;
const write = async (filePath, content) => new Promise((resolve, reject) => {
    fs_1.default.writeFile(filePath, content, err => {
        if (err) {
            return reject(err);
        }
        return resolve(true);
    });
});
exports.write = write;
const read = async (filePath) => new Promise((resolve, reject) => {
    fs_1.default.promises
        .readFile(filePath, 'utf8')
        .then(data => {
        resolve(data);
    })
        .catch(error => {
        reject(error);
    });
});
exports.read = read;
const copyFile = async (src, dest) => new Promise((resolve, reject) => {
    fs_1.default.copyFile(src, dest, err => {
        if (err) {
            return reject(err);
        }
        return resolve(true);
    });
});
exports.copyFile = copyFile;
const createTarball = async (filePath, outputDir) => new Promise((resolve, reject) => {
    const fileName = path_1.default.basename(filePath);
    tar
        .create({
        gzip: true,
        file: `${outputDir}/${fileName}.tar.gz`,
        cwd: outputDir,
    }, [fileName])
        .then(() => resolve(true))
        .catch(err => reject(err));
});
exports.createTarball = createTarball;
const getFiles = async (directoryPath, options = {}) => new Promise((resolve, reject) => {
    fs_1.default.readdir(directoryPath, options, (err, files) => {
        if (err) {
            return reject(err);
        }
        return resolve(files);
    });
});
exports.getFiles = getFiles;
//# sourceMappingURL=fs.js.map