"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNetworkIdentifier = exports.isPortAvailable = void 0;
const net_1 = require("net");
const client_1 = require("../client");
const constants_1 = require("../constants");
const isPortAvailable = async (port) => new Promise((resolve, reject) => {
    const server = (0, net_1.createServer)();
    server.once('error', (err) => {
        if (err.code === 'EADDRINUSE') {
            resolve(false);
        }
        else {
            reject(err);
        }
    });
    server.once('listening', () => {
        server.close(() => resolve(true));
    });
    server.listen(port);
});
exports.isPortAvailable = isPortAvailable;
const getNetworkIdentifier = async (network, liskCoreV3DataPath) => {
    const networkID = network
        ? (() => {
            const networkConstantEntry = Object.entries(constants_1.NETWORK_CONSTANT).find(([, v]) => v.name === network);
            const [networkIdentifier] = networkConstantEntry;
            return networkIdentifier;
        })()
        : await (async () => {
            const client = await (0, client_1.getAPIClient)(liskCoreV3DataPath);
            const nodeInfo = (await client.node.getNodeInfo());
            return nodeInfo.networkIdentifier;
        })();
    return networkID;
};
exports.getNetworkIdentifier = getNetworkIdentifier;
//# sourceMappingURL=network.js.map